OSSP CVS Repository

ossp - Difference in ossp-pkg/as/as-gui/as_slot.cpp versions 1.30 and 1.31
Not logged in
[Honeypot]  [Browse]  [Home]  [Login]  [Reports
[Search]  [Ticket]  [Timeline
  [History

ossp-pkg/as/as-gui/as_slot.cpp 1.30 -> 1.31

--- as_slot.cpp  2002/12/02 18:10:19     1.30
+++ as_slot.cpp  2002/12/03 17:05:11     1.31
@@ -229,6 +229,7 @@
 {
     m_pMaintable->setReadOnly(false);
     m_pMaintable->editCell(nRow, nCol);
+    m_pMaintable->setEdition(nCol);
     m_pMaintable->setReadOnly(true);
 }
 
@@ -285,6 +286,9 @@
     QString Texttask(m_pMaintable->text(nRow, TITRAQ_IDXTASK));
     QString Textremark(m_pMaintable->text(nRow, TITRAQ_IDXREMARK));
 
+    // Reset the edition state member
+    m_pMaintable->setEdition();
+
     if (!Textdate.isEmpty())
         m_pDateedit->setDate(QDate::fromString(Textdate, Qt::ISODate));
     else
@@ -333,12 +337,21 @@
 }
 
 //
+// View menu normal
+//
+void Titraqform::normalView(void)
+{
+    // All view types except normal are disabled until implemention, so
+    // this body can remain empty, causing nothing to happen on selection.
+}
+
+//
 // View menu editing
 //
 void Titraqform::editingView(void)
 {
     // All other view types are disabled until implemention, so this
     // body can remain empty, causing nothing to happen on selection.
 }
 
 //
@@ -346,8 +359,8 @@
 //
 void Titraqform::timingView(void)
 {
-    Prototype Unimp;
-    Unimp.doMbox();
+    // All view types except normal are disabled until implemention, so
+    // this body can remain empty, causing nothing to happen on selection.
 }
 
 //
@@ -333,12 +337,21 @@
 void Titraqform::editingView(void)
 {
-    // All other view types are disabled until implemention, so this
-    // body can remain empty, causing nothing to happen on selection.
+    // All view types except normal are disabled until implemention, so
+    // this body can remain empty, causing nothing to happen on selection.
 }
 

CVSTrac 2.0.1